# Beisp_01.R - 28.02.2009 
# R Version 2.8.1

# Beispiel 1: Designbasierte Schtzung des Gesamtwertes Zahl der Erwerbslosen 
# - Ohne Ausschluss von PSUs mit nur einer Sekundreinheit
# - Annahme einer einstufigen Zufallsauswahl (f=0,01*0,035)

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# SCHICHTUNG: ef1*10 + ef712  # Schichtung: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) ) # Designgewicht 

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz, 15+ Jahre
sub <- ef505>=1 & ef505<=2 & ef30>=15 # Bev. am HWS, 15+ Jahre

# Konstruktion der interessierenden Variablen 
y <- ef504==2 # ILO-Erwerbslose ohne Bercksichtigung Subpopulation

# Definition des Stichprobendesigns 
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1) x Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
des <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )

# - ohne Rekodierung singulre PSU, Pseudoschicht
options(survey.lonely.psu="certainty")

# Domain Schtzung: y fr sub 
svyby(y, sub, des, svytotal, deff=TRUE, verbose=TRUE, vartype=c("se","cv"))

# Ergebnis
#         V1        se         cv     DEff
# 2874285.71 94763.377 0.03296937 1.148342
#
# R Designeffekt: geringfgige Abweichung zu Stata

