# Beisp_04.R - 01.03.2009 
# R Version 2.8.1

# Beispiel 4: Gruppenvergleiche 

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)


# SCHICHTUNG
schicht = ef1*10 + ef712  # Schichtung: Bundesland (ef1), Gebudegrenklasse (ef712)

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) ) 

# SUBPOPULATION
# Bevlkerung am Hauptwohnsitz (ef505), 15-65 Jahre (ef30), Erwerbspers.
sub <- ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504<=2

# INTERESSIERENDES MERKMAL mit Bercksichtigung Subpopulation
y <- (ef504==2) # ILO-Erwerbslos (ef504)

# West-/Ostdeutschland: 1=West, 2=Ost
westost <- 1+ ( (ef1==11 & ef708==9) | ef1>11 )


# Definition des Stichprobendesigns 
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1), Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
des <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep((0.01 * 0.035), nrow(mz02cf)) )
# singlulre PSU aus Schaetzung ausschlieen:
options(survey.lonely.psu="certainty") # siehe http://faculty.washington.edu/tlumley/survey/exmample-lonely.html

# Domain Schtzung des Gesamtwertes Zahl der Erwerbslosen 
# ... in West-/Ostdeutschland 
svyby(y, westost*sub, des, svytotal, deff=TRUE, verbose=TRUE, vartype=c("se","cvpct"))
# Ergebnis                                      
#   westost       y     se.y    cv%.y   DEff.y  
# 1       1 1677143 72162.37 4.302697 1.157935  
# 2       2 1197143 61777.29 5.160394 1.363293  


# Alternative mit Chi-Quadrat-Statistik
daten <- data.frame(ef3, schicht, w, y, westost, sub)
des <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = daten, f = rep((0.01 * 0.035), nrow(mz02cf)) )
# Selektion: sub>0
dsub<-subset(des,sub>0)
svytable(~westost+y, dsub)
svychisq(~westost+y, dsub, statistic = c("F"))
# Ergebnis:
#        Pearson's X^2: Rao & Scott adjustment
# F = 304.2021, ndf = 1, ddf = 6861, p-value < 2.2e-16

