# Beisp_05.R - 07.03.2009 
# R Version 2.8.1

# Beispiel 5: Gesamtwerte bei gebundener Hochrechnung (Poststratifikation)

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz (ef505), 15+ Jahre (ef30)
sub <- ef505>=1 & ef505<=2 & ef30>=15

# INTERESSIERENDES MERKMAL: ILO-Erwerbslos (ef504) 
y <- ef504==2

# POSTSTRATIFIKATION
# 1a) Anpassungsklassen: Geschl. * Staatsangeh., Sold., Wehrpfl.
anp <- ( (1*(ef32==1 & ef52==1 & ef127!=9 & ef127!=10)) # Deutsche Menner
       + (2*(ef32==2 & ef52==1))                        # Deutsche Frauen
       + (3*(ef32==1 & ef52!=1))                        # Ausl. Mnner
       + (4*(ef32==2 & ef52!=1))                        # Ausl. Frauen
       + (5*(ef32==1 & ef52==1 & ef127==9))             # Zeit-/Berufssoldaten
       + (6*(ef32==1 & ef52==1 & ef127==10)) )          # Wehrpflichtige
# * 1b) Proxy Anpassungsschicht (sub=0 mit extra Anp.schicht)
anpschicht <- (ef1*10 + anp) * sub # Bundesland (ef1) x Anpassungsklassen
# 2) Populationsdaten aus Stichprobe schtzen
#    a) Gewicht: gebundene Hochrechnung (ef750g; in 100) fr Bevlkerung am Hauptwohnsitz (ef505)
w_anp <- (ef750g*100*(ef505<=2))
anpschicht = as.factor(anpschicht)
#    b) Populationsdaten pro Anpassungsschicht (M_k)
pop <- aggregate(w_anp, list(anpschicht), sum)
names(pop) <- c("anpschicht", "M_k")

# DEFINITION DES STICHPROBENDESIGSN fr Designgewichtung (a)
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1), Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )
# ... mit POSTSTRATIFIKATION (b)
psdesgew <- postStratify(desgew, ~anpschicht, data.frame(anpschicht = pop[1], Freq = pop[2]))

# SCHTZUNG GESAMTWERT MIT POSTSTRATIFIKATION
options(survey.lonely.psu="certainty") # singlulre PSU aus Schtzung ausschlieen
svyby(~y, ~sub, psdesgew, svytotal) # Domain estimation: Subpopulation
# Ergebnis:
#  Total: 3428498.70
#  S.E.:   111236.063


