# Beisp_06.R - 08.04.2009
# R Version 2.8.1

# Beispiel 6: Gesamtwerte mit gebundener Hochrechnung (Regressionsschtzung)

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# Satznummer
ID = 1:nrow(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
d <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz (ef505), 15+ Jahre (ef30)
sub <- (ef505>=1 & ef505<=2 & ef30>=15)

# INTERESSIERENDES MERKMAL: ILO-Erwerbslos (ef504) 
y <- (ef504==2)     # ohne Bercksichtigung Subpopulation


# 1) Proxy Anpassungsschicht
#    Anpassungsklassen: Geschl. * Staatsangeh., Sold., Wehrpfl.
anp <- ( (1*(ef32==1 & ef52==1 & ef127!=9 & ef127!=10)) # Deutsche Menner
       + (2*(ef32==2 & ef52==1))                        # Deutsche Frauen
       + (3*(ef32==1 & ef52!=1))                        # Ausl. Mnner
       + (4*(ef32==2 & ef52!=1))                        # Ausl. Frauen
       + (5*(ef32==1 & ef52==1 & ef127==9))             # Zeit-/Berufssoldaten
       + (6*(ef32==1 & ef52==1 & ef127==10)) )          # Wehrpflichtige
#    Proxy Anpassungsschicht (sub=0 mit extra Anp.schicht)
anpschicht <- (ef1*10 + anp) * sub # Bundesland (ef1) x Anpassungsklassen

# Populationswerte geb. Hochrechnung
Z <- aggregate( (ef750g*100*(ef505<=2)), list(as.factor(anpschicht)), sum)

# Design: Klumpung, Schichtung, Designgewichtung, Endlichkeitskorrektur
desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~d, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )

# singlulre PSU aus Schtzung ausschlieen
options(survey.lonely.psu="certainty")

# Designdefinition fr Regressionsschtzung
# desg <- calibrate(desgew, ~anps, pop=Z[,2])
desg <- calibrate(desgew, ~as.factor(anpschicht), pop=Z[,2])

# Domain estimation: Subpopulation
svyby(~y, ~sub, desg, svytotal)
# Ergebnis:
#         sub    yFALSE      yTRUE se.yFALSE  se.yTRUE
# FALSE FALSE -58345709  -74061.58  33077.62  33077.62
# TRUE   TRUE  66977207 3428498.70 111236.06 111236.06

