# Beisp_07.R - 30.03.2009 
# R Version 2.8.1

# Beispiel 7: Erwerbslosenquote mit Designgewichtung

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# Satznummer
ID = 1:nrow(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# Region: West-/Ostdeutschland: 1=West, 2=Ost
westost <- 1+ ( (ef1==11 & ef708==9) | ef1>11 )

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz (ef505), 15-65 Jahre (ef30), Erwerbspersonen (ef504)
sub = 1*(ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2)

# Altersgruppen 
# alter = 0*(ef30<=14) + 1*(ef30>=15 & ef30<=24) + 2*(ef30>=25 & ef30<=54) + 3*(ef30>=55 & ef30<=65) + 4*(ef30>=66 & ef30<=99)
alter = (1*(ef30>=15 & ef30<=24) + 2*(ef30>=25 & ef30<=54) + 3*(ef30>=55 & ef30<=65))*sub


# INTERESSIERENDES ZHLERMERKMAL: ILO-Erwerbslos (ef504) 
y = 1*(ef504==2) # ohne Bercksichtigung Subpopulation

# NENNERMERKMAL: Erwerbspersonen 
x = 1*(ef504>=1 & ef504<=2) # ohne Bercksichtigung Subpopulation

# VERHLTNISWERT y/x
r <- ifelse(y==0 | x==0, 0, y/x)

desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )
options(survey.lonely.psu="certainty") # singlulre PSU aus Schtzung ausschlieen
svyby(r, by=alter, design=desgew, svymean)
#   by          V1           se
# 0  0 0.000377387 0.0001687168
# 1  1 0.116607774 0.0087993356
# 2  2 0.075249723 0.0029033931
# 3  3 0.111414901 0.0085066557
# OK 

# z:= Subpopulation x Westost x Alter
z = 1*(westost==1 & alter==1) + 2*(westost==1 & alter==2) + 3*(westost==1 & alter==3) + 4*(westost==2 & alter==1) + 5*(westost==2 & alter==2) + 6*(westost==2 & alter==3) 
svyby(r, by=z, design=desgew, svymean)
# R-Ergebnisse
#   by          V1           se
# 0  0 0.000377387 0.0001687168
# 1  1 0.088392857 0.0086881176   | West 15-24
# 2  2 0.054172969 0.0027738015   |      25-54
# 3  3 0.079124579 0.0079383769   |      55-65
# 4  4 0.223728814 0.0252689796   | Ost  15-24
# 5  5 0.163500288 0.0093315548   |      25-54
# 6  6 0.250909091 0.0278870300   |      55-65





