# Beisp_08.R - 30.03.2009 
# R Version 2.8.1

# Beispiel 8: Erwerbslosenquote mit gebundener Hochrechnung (Poststratifikation)

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# Satznummer
ID = 1:nrow(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# Region: West-/Ostdeutschland: 1=West, 2=Ost
westost <- 1+ ( (ef1==11 & ef708==9) | ef1>11 )

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz (ef505), 15-65 Jahre (ef30), Erwerbspersonen (ef504)
sub = 1*(ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2)

# Altersgruppen 
alter = (1*(ef30>=15 & ef30<=24) + 2*(ef30>=25 & ef30<=54) + 3*(ef30>=55 & ef30<=65))*sub

# INTERESSIERENDES ZHLERMERKMAL: ILO-Erwerbslos (ef504) 
y = 1*(ef504==2)  # ohne Bercksichtigung Subpopulation

# NENNERMERKMAL: Erwerbspersonen 
x = 1*(ef504>=1 & ef504<=2) # ohne Bercksichtigung Subpopulation

# VERHLTNISWERT y/x
r <- ifelse(y==0 | x==0, 0, y/x)

# z:= Subpopulation x Westost x Alter
z = 1*(westost==1 & alter==1) + 2*(westost==1 & alter==2) + 3*(westost==1 & alter==3) + 4*(westost==2 & alter==1) + 5*(westost==2 & alter==2) + 6*(westost==2 & alter==3) 

# 1) Proxy Anpassungsschicht
#    Anpassungsklassen: Geschl. * Staatsangeh., Sold., Wehrpfl.
anp <- ( (1*(ef32==1 & ef52==1 & ef127!=9 & ef127!=10)) # Deutsche Menner
       + (2*(ef32==2 & ef52==1))                        # Deutsche Frauen
       + (3*(ef32==1 & ef52!=1))                        # Ausl. Mnner
       + (4*(ef32==2 & ef52!=1))                        # Ausl. Frauen
       + (5*(ef32==1 & ef52==1 & ef127==9))             # Zeit-/Berufssoldaten
       + (6*(ef32==1 & ef52==1 & ef127==10)) )          # Wehrpflichtige
#    Proxy Anpassungsschicht (sub=0 mit extra Anp.schicht)
anpschicht <- (ef1*10 + anp) * sub # Bundesland (ef1) x Anpassungsklassen

anpschicht = as.factor(anpschicht)
w_anp <- (ef750g*100*(ef505<=2))
#    b) Populationsdaten pro Anpassungsschicht (M_k)
pop <- aggregate(w_anp, list(anpschicht), sum)
names(pop) <- c("anpschicht", "M_k")

# DEFINITION DES STICHPROBENDESIGSN fr Designgewichtung (a)
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1), Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )
# ... mit POSTSTRATIFIKATION (b)
psdesgew <- postStratify(desgew, ~anpschicht, data.frame(anpschicht = pop[1], Freq = pop[2]))
options(survey.lonely.psu="certainty") # singlulre PSU aus Schtzung ausschlieen

# SCHTZUNG VERHLTNISWERT MIT POSTSTRATIFIKATION
svyby(~r, by=~alter, design=psdesgew, svymean) # Domain estimation: Altersgruppe x Subpopulation
# R-Ergebnis
#   alter           r         se.r
# 0     0 0.000377387 0.0001687168   | nicht Subpopulation oder <15 oder >66 Jahre
# 1     1 0.118999296 0.0089160956   | 15-24 Jahre
# 2     2 0.077072785 0.0029242422   | 25-54 Jahre
# 3     3 0.113679845 0.0086667890   | 55-65 Jahre

svyby(~r, by=~z, design=psdesgew, svymean)
# R-Ergebnis
#   z           r         se.r
# 0 0 0.000377387 0.0001687168
# 1 1 0.092341589 0.0090615575 | West, 15-24
# 2 2 0.056184299 0.0028613064 |       25-54
# 3 3 0.081499331 0.0082296439 |       55-65
# 4 4 0.221173341 0.0246440280 | Ost   15-24
# 5 5 0.165710257 0.0093260208 |       25-54
# 6 6 0.253314980 0.0278233330 |       55-65


