# Beisp_09.R - 30.03.2009 
# R Version 2.8.1

# * Beispiel 9: Durchschnittliche Arbeitsstunden (Designgewichtung) 

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# Satznummer
ID = 1:nrow(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# Region: West-/Ostdeutschland: 1=West, 2=Ost
westost <- 1+ ( (ef1==11 & ef708==9) | ef1>11 )

# z:= Kombination Geschlecht x Region
z = 1*(ef32==1 & westost==1) + 2*(ef32==1 & westost==2) + 3*(ef32==2 & westost==1) + 4*(ef32==2 & westost==2)

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz, Erwerbsttige
sub = 1*(ef505>=1 & ef505<=2 & ef504==1)

# INTERESSIERENDES MERKMAL
# ef141 Normalerw. geleist. Arbeitszeit (Std.) je Woche
y <- ifelse(ef141==57, 58, ef141)
y <- ifelse(ef141==60, 62, y)
y <- ifelse(ef141==65, 67, y)
y <- ifelse(ef141==70, 72, y)
y <- ifelse(ef141==75, 77, y)
y <- ifelse(ef141==80, 82, y)
y <- ifelse(ef141==85, 87, y)
y <- ifelse(ef141==90, 93.5, y)

# DEFINITION DES STICHPROBENDESIGSN fr Designgewichtung (a)
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1), Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )
options(survey.lonely.psu="certainty") # singlulre PSU aus Schtzung ausschlieen
svyby(y, by=sub * z, design=desgew, svymean) # Domain estimation: Subpopulation

# R-Ergebnis:
#   by         V1         se
# 0  0  0.5505944 0.04931759  | nicht Subpopulation
# 1  1 40.7423520 0.16290355  | Mnnlich, West
# 2  2 40.2103659 0.27930787  |           Ost
# 3  3 30.8644837 0.21607158  | Weiblich, West
# 4  4 35.2890110 0.32939195  |           Ost


