# Beisp_10.R - 30.03.2009 
# R Version 2.8.1

# * Beispiel 10: Durchschnittliche Arbeitsstunden 
#                mit  gebundener Hochrechnung
#                (Poststratifikation)

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)

# Satznummer
ID = 1:nrow(mz02cf)

# SCHICHTUNG: Bundesland (ef1), Gebudegrenklasse (ef712)
schicht = ef1*10 + ef712 

# DESIGNGEWICHT
w <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) )

# Region: West-/Ostdeutschland: 1=West, 2=Ost
westost <- 1+ ( (ef1==11 & ef708==9) | ef1>11 )

# z:= Kombination Geschlecht x Region
z = 1*(ef32==1 & westost==1) + 2*(ef32==1 & westost==2) + 3*(ef32==2 & westost==1) + 4*(ef32==2 & westost==2)

# SUBPOPULATION: Bevlkerung am Hauptwohnsitz, Erwerbsttige
sub = 1*(ef505>=1 & ef505<=2 & ef504==1)

# INTERESSIERENDES MERKMAL
# ef141 Normalerw. geleist. Arbeitszeit (Std.) je Woche
y <- ifelse(ef141==57, 58, ef141)
y <- ifelse(ef141==60, 62, y)
y <- ifelse(ef141==65, 67, y)
y <- ifelse(ef141==70, 72, y)
y <- ifelse(ef141==75, 77, y)
y <- ifelse(ef141==80, 82, y)
y <- ifelse(ef141==85, 87, y)
y <- ifelse(ef141==90, 93.5, y)

# 1) Proxy Anpassungsschicht
#    Anpassungsklassen: Geschl. * Staatsangeh., Sold., Wehrpfl.
anp <- ( (1*(ef32==1 & ef52==1 & ef127!=9 & ef127!=10)) # Deutsche Menner
       + (2*(ef32==2 & ef52==1))                        # Deutsche Frauen
       + (3*(ef32==1 & ef52!=1))                        # Ausl. Mnner
       + (4*(ef32==2 & ef52!=1))                        # Ausl. Frauen
       + (5*(ef32==1 & ef52==1 & ef127==9))             # Zeit-/Berufssoldaten
       + (6*(ef32==1 & ef52==1 & ef127==10)) )          # Wehrpflichtige
#    Proxy Anpassungsschicht (sub=0 mit extra Anp.schicht)
anpschicht <- (ef1*10 + anp) * sub # Bundesland (ef1) x Anpassungsklassen

anpschicht = as.factor(anpschicht)
w_anp <- (ef750g*100*(ef505<=2))
#    b) Populationsdaten pro Anpassungsschicht (M_k)
pop <- aggregate(w_anp, list(anpschicht), sum)
names(pop) <- c("anpschicht", "M_k")

# DEFINITION DES STICHPROBENDESIGSN fr Designgewichtung (a)
# - Einstufige Klumpenauswahl: Auswahlbezirke (ef3) 
# - Schichtung: Bundesland (ef1), Gebudeschicht (ef712) 
# - Endlichkeitskorrektur mit Auswahlsatz f = 0,00035 
desgew <- svydesign(id = ~ef3, strata = ~schicht, weight = ~w, data = mz02cf, f = rep( (0.01 * 0.035), nrow(mz02cf) ) )
# ... mit POSTSTRATIFIKATION (b)
psdesgew <- postStratify(desgew, ~anpschicht, data.frame(anpschicht = pop[1], Freq = pop[2]))
options(survey.lonely.psu="certainty") # singlulre PSU aus Schtzung ausschlieen

# SCHTZUNG MITTELWERT MIT POSTSTRATIFIKATION
svyby(~y, by=sub * z, design=psdesgew, svymean) # Domain estimation: Altersgruppe x Subpopulation

# R-Ergebnis
#   by          y       se.y
# 0  0  0.5505944 0.04931759 | nicht Subpopulation
# 1  1 40.6811379 0.16099887 | Mnnlich, West
# 2  2 40.1756319 0.27678579 |           Ost
# 3  3 30.8438540 0.21699839 | Weiblich, West
# 4  4 35.2746702 0.32782293 |           Ost
