# Beisp_11.R - 30.03.2009 
# R Version 2.8.1

# Beispiel 11: Regression des Monatsnettoeinkommens auf Bildung, Geschlecht
#              und Staatsangehrigkeit

# Quelle: 
# Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
# Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
# File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS.
# URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
#      gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
# Diese Datei:
# http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
#     sp-fehler/R_Beispiele.zip

detach()
rm(list=ls(all=TRUE))  # Speicher loeschen

library(survey)   # Version 3.11-2
library(foreign)  # Version 0.8-33

mz02cf<-read.dta(file = "mz02cf_Beisp.dta", convert.factors = FALSE)
attach(mz02cf)


# Allgemeiner Bildungsabschluss - typische Ausbildungsdauer
x287 <- ifelse(ef287==1, 9, NA)               # Hauptschule
x287 <- ifelse(ef287>=2 & ef287<=3, 10, x287) # Realschule, POS
x287 <- ifelse(ef287==4, 12, x287)            # FHR 
x287 <- ifelse(ef287==5, 13, x287)            # Abitur
x287 <- ifelse(ef287==0, 8, x287)             # ohne Abschluss
x287 <- ifelse(ef286==0 | ef286==9, NA, x287) # k.A., Entfllt


# Beruflicher Abschluss - typische Ausbildungsdauer
x289 <- ifelse(ef289==0, 0, NA)                         # ohne Abschluss
x289 <- ifelse(ef289>=1 & ef289<=2, 1, x289)            # Anlernausb., BVJ
x289 <- ifelse(ef289==3 | ef289==7 | ef289==8, 3, x289) # Lehre, FH, Verw.FH
x289 <- ifelse(ef289>=4 & ef289<=6, 2, x289)            # BFS, Meister, FS DDR
x289 <- ifelse(ef289==9, 5, x289)                       # Uni
x289 <- ifelse(ef289==10, 7, x289)                      # Prom.
x289 <- ifelse(ef288==0 | ef288==9, NA, x289)           # k.A., Entfllt


# Rekodierung Nettoeinkommen - Klassenmitte bzw.
#   obere Randklasse  = 150% * Untergrenze
v372m <- ifelse(ef372==1, 75, NA) 
v372m <- ifelse(ef372==2, 225, v372m) 
v372m <- ifelse(ef372==3, 400, v372m) 
v372m <- ifelse(ef372==4, 600, v372m) 
v372m <- ifelse(ef372==5, 800, v372m) 
v372m <- ifelse(ef372==6, 1000, v372m) 
v372m <- ifelse(ef372==7, 1200, v372m)
v372m <- ifelse(ef372==8, 1400, v372m) 
v372m <- ifelse(ef372==9, 1600, v372m) 
v372m <- ifelse(ef372==10, 1850, v372m) 
v372m <- ifelse(ef372==11, 2150, v372m) 
v372m <- ifelse(ef372==12, 2450, v372m) 
v372m <- ifelse(ef372==13, 2750, v372m) 
v372m <- ifelse(ef372==14, 3050, v372m)
v372m <- ifelse(ef372==15, 3400, v372m) 
v372m <- ifelse(ef372==16, 3800, v372m) 
v372m <- ifelse(ef372==17, 4250, v372m) 
v372m <- ifelse(ef372==18, 4750, v372m)
v372m <- ifelse(ef372==19, 5250, v372m) 
v372m <- ifelse(ef372==20, 5750, v372m) 
v372m <- ifelse(ef372==21, 6750, v372m) 
v372m <- ifelse(ef372==22, 8750, v372m) 
v372m <- ifelse(ef372==23, 14000, v372m) 
v372m <- ifelse(ef372==24, 27000, v372m) 
v372m <- ifelse(ef372>=50, NA, v372m)
logv372m <- ifelse(ef372>0 & ef372<50, log(v372m), 0)


# Geschlecht: 0=mnnlich  1=weiblich
v32 <- ef32-1


# Staatsangehrigkeit  0=Deutsch  1=Auslnder
v52 <- ifelse(ef52>=2 & ef52<=3, 1, 0)


# Subpopulation: Bevlkerung am Hauptwohnsitz (ef505), 
#    Abh. Beschftigte (ohne Azubis) (ef127), Erwerbsttige (ef504), 
#    berw. Lebensunterhalt = Erwerbsttigk. (ef338), gltige 
#    Einkommensangaben (ef372), gltige Angaben allg. Bildungsabschluss (x287),
#    gltige Angaben berufl. Abschluss (x289)
sub <- 0 + (ef505>=1 & ef505<=2 & ef127>=4 & ef127<=6 & ef504==1 & ef338==1 & 
        ef372>=1 & ef372<=24 & x287>=8 & x287<=13 & x289>=0 & x289<=7)

# (1) OLS (SRSWR)
summary(lm(logv372m ~ x287 + x289 + v32 + v52, subset=sub==1))
# Ergebnis
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  6.406516   0.040388 158.625   <2e-16 ***
# x287         0.077672   0.004182  18.573   <2e-16 ***
# x289         0.083770   0.005136  16.311   <2e-16 ***
# v32         -0.495402   0.011845 -41.823   <2e-16 ***
# v52         -0.051030   0.025609  -1.993   0.0463 *  
# (...)
# Multiple R-squared: 0.275,      Adjusted R-squared: 0.2746 



# (2) Robuste Varianzschtzung, Klumpung: Auswahlbezirk (SRSWR).
d <- rep( (1/(0.01 * 0.035)), nrow(mz02cf) ) # Designgewicht
D <- data.frame(ef3, d, logv372m, x287, x289, v32, v52, subset=sub==1)
DSUB <- subset(D, subset, keep = sub==1)     # Daten fr Subpopulation
desgew <- svydesign(id=~ef3, weight=~d, data=DSUB)
rob <- svyglm(logv372m~x287+x289+v32+v52, desgew, family=gaussian(link = "identity"))
summary(rob)
# Ergebnis
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept)  6.406516   0.042937 149.206   <2e-16 ***
# x287         0.077672   0.004783  16.240   <2e-16 ***
# x289         0.083770   0.006173  13.569   <2e-16 ***
# v32         -0.495402   0.012351 -40.109   <2e-16 ***
# v52         -0.051030   0.025689  -1.986    0.047 *  

